import * as THREE from "three";
import { EffectComposer, N8AO, Outline } from "@react-three/postprocessing";
import { BlendFunction } from "postprocessing";
import {
    useDeletableFloorItem,
    useSelectedWallItem,
    useSelectedFloorItem,
} from "../../../store/builder/store";
import * as Types from "../../../types/world/worldTypes";
import * as CONSTANTS from "../../../types/world/worldConstants";
import { useEffect } from "react";
import { useSelectedEventSphere } from "../../../store/simulation/useSimulationStore";

export default function PostProcessing() {
    const { deletableFloorItem, setDeletableFloorItem } = useDeletableFloorItem();
    const { selectedWallItem, setSelectedWallItem } = useSelectedWallItem();
    const { selectedFloorItem, setSelectedFloorItem } = useSelectedFloorItem();
    const { selectedEventSphere } = useSelectedEventSphere();

    function flattenChildren(children: any[]) {
        const allChildren: any[] = [];
        children.forEach((child) => {
            allChildren.push(child);
            if (child.children && child.children.length > 0) {
                allChildren.push(...flattenChildren(child.children));
            }
        });
        return allChildren;
    }

    return (
        <>
            <EffectComposer autoClear={false}>
                <N8AO
                    color="black"
                    aoRadius={20}
                    intensity={7}
                    distanceFalloff={4}
                    aoSamples={32}
                    denoiseRadius={6}
                    denoiseSamples={16}
                />
                {deletableFloorItem && (
                    <Outline
                        selection={flattenChildren(deletableFloorItem.children)}
                        selectionLayer={10}
                        width={3000}
                        blendFunction={BlendFunction.ALPHA}
                        edgeStrength={5}
                        resolutionScale={2}
                        pulseSpeed={0}
                        visibleEdgeColor={CONSTANTS.outlineConfig.assetDeleteColor}
                        hiddenEdgeColor={CONSTANTS.outlineConfig.assetDeleteColor}
                        blur={true}
                        xRay={true}
                    />
                )}
                {selectedWallItem && (
                    <Outline
                        selection={flattenChildren(selectedWallItem.children)}
                        selectionLayer={10}
                        width={3000}
                        blendFunction={BlendFunction.ALPHA}
                        edgeStrength={5}
                        resolutionScale={2}
                        pulseSpeed={0}
                        visibleEdgeColor={CONSTANTS.outlineConfig.assetSelectColor}
                        hiddenEdgeColor={CONSTANTS.outlineConfig.assetSelectColor}
                        blur={true}
                        xRay={true}
                    />
                )}
                {selectedFloorItem && (
                    <Outline
                        selection={flattenChildren(selectedFloorItem.children)}
                        selectionLayer={10}
                        width={3000}
                        blendFunction={BlendFunction.ALPHA}
                        edgeStrength={5}
                        resolutionScale={2}
                        pulseSpeed={0}
                        visibleEdgeColor={CONSTANTS.outlineConfig.assetSelectColor}
                        hiddenEdgeColor={CONSTANTS.outlineConfig.assetSelectColor}
                        blur={true}
                        xRay={true}
                    />
                )}
                {selectedEventSphere && (
                    <Outline
                        selection={[selectedEventSphere]}
                        selectionLayer={10}
                        width={1000}
                        blendFunction={BlendFunction.ALPHA}
                        edgeStrength={10}
                        resolutionScale={2}
                        pulseSpeed={0}
                        visibleEdgeColor={0x6f42c1}
                        hiddenEdgeColor={0x6f42c1}
                        blur={true}
                        xRay={true}
                    />
                )}
            </EffectComposer>
        </>
    );
}
